====================
DataType expressions
====================
.. currentmodule:: polars

Data type expressions allow lazily determining a datatype of a column or
expression and using in expressions.

This page gives an overview of all public Polars expressions.

.. toctree::
   :maxdepth: 2
   :hidden:

   dt_functions
   dt_list
   dt_array
   dt_struct

.. currentmodule:: polars

.. autoclass:: DataTypeExpr
    :members:
    :noindex:
    :autosummary:
    :autosummary-nosignatures:
